ProtocolWriter

Struct ProtocolWriter 

pub struct ProtocolWriter<W> { /* private fields */ }
Manages a buffer to automatically encrypt and send contents in packets.

Implementations

Source

impl<W> ProtocolWriter<W>
where W: Write,

pub fn write(&mut self, payload: &Payload) -> Result<(), ProtocolError>

Encrypt payload and write packet to the internal writer.

Arguments
  • payload - The payload to encrypt and send.
Returns

A Result containing:

  • Ok(): On successful payload encryption and packet send.
  • Err(ProtocolError): An error that occurred during the encryption or write.
pub fn into_inner(self) -> (OutboundCipher, W)

Consume the protocol writer in exchange for the underlying writer and cipher.