pub struct ProtocolWriter<W> { /* private fields */ }Expand description
Manages a buffer to automatically encrypt and send contents in packets.
Implementations
Sourceimpl<W> ProtocolWriter<W>where
W: Write,
impl<W> ProtocolWriter<W>where
W: Write,
Sourcepub fn into_inner(self) -> (OutboundCipher, W)
pub fn into_inner(self) -> (OutboundCipher, W)
Consume the protocol writer in exchange for the underlying writer and cipher.